@@ -93,7 +93,7 @@ class Processor(base.ResourceBase):
     """The total number of execution threads supported by this processor"""
 
     def __init__(self, connector, identity, redfish_version=None,
-                 registries=None):
+                 registries=None, root=None):
         """A class representing a Processor
 
         :param connector: A Connector instance
@@ -102,9 +102,11 @@ class Processor(base.ResourceBase):
             the object according to schema of the given version.
         :param registries: Dict of Redfish Message Registry objects to be
             used in any resource that needs registries to parse messages
+        :param root: Sushy root object. Empty for Sushy root itself.
         """
         super(Processor, self).__init__(
-            connector, identity, redfish_version, registries)
+            connector, identity, redfish_version=redfish_version,
+            registries=registries, root=root)
 
     def _get_subprocessor_collection_path(self):
         """Helper function to find the SubProcessors path"""
@@ -120,7 +122,7 @@ class Processor(base.ResourceBase):
         """A reference to the collection of Sub-Processors"""
         return ProcessorCollection(
             self._conn, self._get_subprocessor_collection_path(),
-            redfish_version=self.redfish_version)
+            redfish_version=self.redfish_version, root=self.root)
 
 
 class ProcessorCollection(base.ResourceCollectionBase):
@@ -156,7 +158,8 @@ class ProcessorCollection(base.ResourceCollectionBase):
 
         return ProcessorSummary(count=count, architecture=architecture)
 
-    def __init__(self, connector, path, redfish_version=None, registries=None):
+    def __init__(self, connector, path, redfish_version=None, registries=None,
+                 root=None):
         """A class representing a ProcessorCollection
 
         :param connector: A Connector instance
@@ -165,6 +168,9 @@ class ProcessorCollection(base.ResourceCollectionBase):
             the object according to schema of the given version.
         :param registries: Dict of Redfish Message Registry objects to be
             used in any resource that needs registries to parse messages
+        :param root: Sushy root object. Empty for Sushy root itself.
         """
         super(ProcessorCollection, self).__init__(
-            connector, path, redfish_version, registries)
+            connector, path, redfish_version=redfish_version,
+            registries=registries,
+            root=root)
